Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTon Roosendaal <ton@blender.org>2004-11-12 02:56:56 +0300
committerTon Roosendaal <ton@blender.org>2004-11-12 02:56:56 +0300
commit1c632c40c01d4c0ac88828b7353d9040684e16d4 (patch)
tree50ab68e29d7d79ab689f03b0008b4efa43268d9e /source/blender/src/editobject.c
parent5989da14420597e945386d9fd56310cb2d88ab00 (diff)
Fix for error found by aphex;
Some extrusions still use proportional mode when thats on. Was due to adding transfrom('g') for non-normal extrude. Made it new code 'h'
Diffstat (limited to 'source/blender/src/editobject.c')
-rw-r--r--source/blender/src/editobject.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/source/blender/src/editobject.c b/source/blender/src/editobject.c
index 0e2c112f311..a507f431428 100644
--- a/source/blender/src/editobject.c
+++ b/source/blender/src/editobject.c
@@ -3885,7 +3885,7 @@ void make_trans_verts(float *min, float *max, int mode)
EditVert *eve;
int a;
EditBone *ebo;
-
+
tottrans= 0; // global!
INIT_MINMAX(min, max);
@@ -4945,6 +4945,7 @@ static char *transform_mode_to_string(int mode)
case 'w': return("Warp"); break;
case 'd': return("Duplicate"); break;
case 'n': return("Extrude"); break;
+ case 'h': return("Extrude"); break;
default: return("Transform");
}
}
@@ -5014,8 +5015,8 @@ void transform(int mode)
if(mode=='r') mode= 'R';
if(mode=='s') mode= 'C';
}
- /* from duplicate routines */
- if(mode=='d') mode= 'g';
+ /* from duplicate or extrude routines */
+ if(mode=='d' || mode=='h') mode= 'g';
/* this can cause floating exception at dec alpha */
d_dvec[0]= d_dvec[1]= d_dvec[2]= 0.0;